@@ -17,7 +17,7 @@
 #' @returns A data frame containing the following variables for all NFL games
 #' since 1999:
 #' \describe{
-#' \item{game_id}{The ID of the game as assigned by the NFL. Note that this value matches the `game_id` field in nflscrapR if you wish to join the data.}
+#' \item{game_id}{The ID of the game as assigned by the nflverse. Note that this value matches the `game_id` field in nflfastR if you wish to join the data.}
 # \item{alt_game_id}{This is a more human-readable ID. It consists of: The season, an underscore, the two-digit week number, an underscore, the away team, an underscore, the home team.}
 #' \item{season}{The year of the NFL season. This represents the whole season, so regular season games that happen in January as well as playoff games will occur in the year after this number.}
 #' \item{game_type}{What type of game? One of the following values:
@@ -29,7 +29,7 @@
 #' \item{`SB`}{: a Super Bowl}
 #' }
 #' }
-#' \item{week}{The week of the NFL season the game occurs in. This will be 1-17 for the regular season, 18 for wildcard playoff games, 19 for divisional playoff games, 20 for conference championships and 21 for Super Bowls.}
+#' \item{week}{The week of the NFL season the game occurs in. Please note that the `game_type` will differ for weeks >= 18 because of the season expansion in 2021. Please use `game_type` to filter for regular season or postseason.}
 #' \item{gameday}{The date on which the game occurred.}
 #' \item{weekday}{The day of the week on which the game occurred.}
 #' \item{gametime}{The kickoff time of the game. This is represented in 24-hour time and the Eastern time zone, regardless of what time zone the game was being played in.}
@@ -91,7 +91,7 @@
 #' }
 #' @export
 load_sharpe_games <- function(){
-  fetched <- try(curl::curl_fetch_memory("https://github.com/leesharpe/nfldata/blob/master/data/games.rds?raw=true"), silent = TRUE)
+  fetched <- try(curl::curl_fetch_memory("https://github.com/nflverse/nfldata/blob/master/data/games.rds?raw=true"), silent = TRUE)
   if (inherits(fetched, "try-error") || fetched$status_code != 200) return(tibble::tibble())
   read_raw_rds(fetched$content)
 }
